geowatch.tasks.tracking.abstract\_classes module
================================================

.. automodule:: geowatch.tasks.tracking.abstract_classes
   :members:
   :undoc-members:
   :show-inheritance:
